from .binary_settings import BinarySettings as BinarySettings
from .command_code import CommandCode as CommandCode
from .connection import Connection as Connection
from .error_code import ErrorCode as ErrorCode
from .message import Message as Message
from .reply_code import ReplyCode as ReplyCode
from .reply_only_event import ReplyOnlyEvent as ReplyOnlyEvent
from .unknown_response_event import UnknownResponseEvent as UnknownResponseEvent
from .device_identity import DeviceIdentity as DeviceIdentity
from .device_settings import DeviceSettings as DeviceSettings
from .device_type import DeviceType as DeviceType
from .device import Device as Device



# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #
# pylint: disable=W0201

from typing import Optional  # pylint: disable=unused-import
from ..protobufs import main_pb2


class AxisMapping:
    """
    Maps a translator axis to a Zaber stream axis.
    """

    def __init__(
            self: 'AxisMapping',
            axis_letter: str,
            axis_index: int
    ) -> None:
        self._axis_letter = axis_letter
        self._axis_index = axis_index

    @property
    def axis_letter(self) -> str:
        """
        Letter of the translator axis (X,Y,Z,A,B,C,E).
        """

        return self._axis_letter

    @axis_letter.setter
    def axis_letter(self, value: str) -> None:
        self._axis_letter = value

    @property
    def axis_index(self) -> int:
        """
        Index of the stream axis.
        """

        return self._axis_index

    @axis_index.setter
    def axis_index(self, value: int) -> None:
        self._axis_index = value

    def __repr__(self) -> str:
        return str(self.__dict__)

    @staticmethod
    def to_protobuf(source: 'Optional[AxisMapping]') -> main_pb2.TranslatorAxisMapping:
        if source is None:
            return main_pb2.TranslatorAxisMapping()

        if not isinstance(source, AxisMapping):
            raise TypeError("Provided value is not AxisMapping.")

        pb_data = main_pb2.TranslatorAxisMapping()
        pb_data.axis_letter = source.axis_letter
        pb_data.axis_index = source.axis_index
        return pb_data



# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #
# pylint: disable=W0201

from typing import Optional  # pylint: disable=unused-import
from .protobufs import main_pb2


class FirmwareVersion:
    """
    Class representing version of firmware in the controller.
    """

    def __init__(
            self: 'FirmwareVersion',
            major: int,
            minor: int,
            build: int
    ) -> None:
        self._major = major
        self._minor = minor
        self._build = build

    @property
    def major(self) -> int:
        """
        Major version number.
        """

        return self._major

    @major.setter
    def major(self, value: int) -> None:
        self._major = value

    @property
    def minor(self) -> int:
        """
        Minor version number.
        """

        return self._minor

    @minor.setter
    def minor(self, value: int) -> None:
        self._minor = value

    @property
    def build(self) -> int:
        """
        Build version number.
        """

        return self._build

    @build.setter
    def build(self, value: int) -> None:
        self._build = value

    def __repr__(self) -> str:
        return str(self.__dict__)

    @staticmethod
    def from_protobuf(
        pb_data: main_pb2.FirmwareVersion
    ) -> 'FirmwareVersion':
        instance = FirmwareVersion.__new__(
            FirmwareVersion
        )  # type: FirmwareVersion
        instance.major = pb_data.major
        instance.minor = pb_data.minor
        instance.build = pb_data.build
        return instance

    @staticmethod
    def to_protobuf(source: 'Optional[FirmwareVersion]') -> main_pb2.FirmwareVersion:
        if source is None:
            return main_pb2.FirmwareVersion()

        if not isinstance(source, FirmwareVersion):
            raise TypeError("Provided value is not FirmwareVersion.")

        pb_data = main_pb2.FirmwareVersion()
        pb_data.major = source.major
        pb_data.minor = source.minor
        pb_data.build = source.build
        return pb_data



from setuptools import setup, find_packages

from os import path


def read_from_file(*filename):
    with open(path.join(*filename), 'r') as f:
        return f.read()


setup(
    name='zaber_motion',
    version='3.4.2',
    packages=find_packages(exclude=["test*", "test_*", "*_test*"]),
    package_data={
        '': ['*.pyi', 'py.typed']
    },
    description='A library for communicating with Zaber devices',
    long_description=read_from_file('DESCRIPTION.md'),
    long_description_content_type="text/markdown",
    url='https://gitlab.com/ZaberTech/zaber-motion-lib',
    author='Zaber Technologies Inc.',
    author_email='contact@zaber.com',
    license='MIT',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries',
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
    ],
    keywords='',
    python_requires='>=3.8',
    install_requires=[
        'protobuf>=3.20.0,<4.22.0',
        'rx>=3.0.0',
        'zaber_motion_bindings_windows==3.4.2;platform_system=="Windows"',
        'zaber_motion_bindings_linux==3.4.2;platform_system=="Linux"',
        'zaber_motion_bindings_darwin==3.4.2;platform_system=="Darwin"',
    ],
)
